import pathlib

import deadlink


def test_cli():
    this_dir = pathlib.Path(__file__).resolve().parent
    files = str((this_dir / ".." / "README.md").resolve())
    deadlink.cli(["check", files, "-a", "http", "-i", "xyz"])



import tempfile
from pathlib import Path

import pytest

import deadlink


def test_replace():
    content = (
        "some text\n"
        + "http://example.com\n"
        + "http://example.com/path\n"
        + "more text"
    )
    d = {
        "http://example.com/path": "http://example.com/path/more",
        "http://example.com": "http://example.com/home",
    }
    new_content = deadlink._main.replace_in_string(content, d)

    ref = (
        "some text\n"
        + "http://example.com/home\n"
        + "http://example.com/path/more\n"
        + "more text"
    )
    assert ref == new_content


@pytest.mark.parametrize(
    "content, ref",
    [
        (
            "some text\nhttps://httpstat.us/301\nmore text",
            "some text\nhttps://httpstat.us\nmore text",
        ),
        # For some reason, http://www.google.com doesn't get redirected
        # https://stackoverflow.com/q/68303464/353337
        # (
        #     "http://www.google.com",
        #     "https://www.google.com"
        # )
    ],
)
def test_fix_cli(content, ref):

    with tempfile.TemporaryDirectory() as tmpdir:
        tmpdir = Path(tmpdir)
        infile = tmpdir / "in.txt"
        with open(infile, "w") as f:
            f.write(content)

        deadlink.cli(["replace-redirects", str(infile), "--yes"])

        with open(infile) as f:
            out = f.read()

        assert out == ref



import pytest

import deadlink


@pytest.mark.parametrize(
    "url,category",
    [
        ("https://httpstat.us/200", "OK"),
        ("https://httpstat.us/404", "Client errors"),
        ("https://this-doesnt-exist.doesit", "Other HTTP errors"),
        ("https://httpstat.us/301", "Successful permanent redirects"),
        ("https://httpstat.us/302", "Non-permanent redirects"),
        ("https://httpstat.us/308", "Successful permanent redirects"),
        ("https://httpstat.us/500", "Server errors"),
        ("https://httpstat.us/200?sleep=99999", "Timeouts"),
        ("https://httpstat.us/XYZ", "Ignored"),
    ],
)
def test_check(url, category):
    print(url)
    out = deadlink.categorize_urls(
        {url}, timeout=1.0, is_allowed=lambda url: "XYZ" not in url
    )
    print(out)
    assert len(out[category]) == 1
    deadlink._main.print_to_screen(out)


def test_preserve_fragment():
    url = "http://www.numpy.org/devdocs/dev/development_workflow.html#writing-the-commit-message"
    url2 = "https://numpy.org/devdocs/dev/development_workflow.html#writing-the-commit-message"
    out = deadlink.categorize_urls({url})
    assert out["Successful permanent redirects"][0][-1].url == url2


@pytest.mark.skip("URL doesn't exist anymore")
def test_relative_redirect():
    url = "http://numpy-discussion.10968.n7.nabble.com/NEP-31-Context-local-and-global-overrides-of-the-NumPy-API-tp47452p47472.html"
    url2 = "http://numpy-discussion.10968.n7.nabble.com/NEP-31-Context-local-and-global-overrides-of-the-NumPy-API-td47452.html#a47472"
    out = deadlink.categorize_urls({url})
    assert out["Successful permanent redirects"][0][-1].url == url2
